@@ -15,6 +15,9 @@ class BasicGuild(DictObject):
     def id(self):
         return self._data.get("id")
 
+    def __repr__(self):
+        return "BasicGuild (id: {})".format(self.id)
+
 
 class Guild(BasicGuild):
 
@@ -95,11 +98,8 @@ class Guild(BasicGuild):
     def website(self):
         return self._data.get("website")
 
-    def __str__(self):
-        return "BGG Guild: {}".format(self.name, self.id)
-
     def __repr__(self):
-        return "guild: {} (id: {})".format(self.name, self.id)
+        return "Guild (id: {})".format(self.id)
 
     def __iter__(self):
         for member in self._data.get("members"):
